# Changelog

All notable changes to the Renovo project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

### Changed

## [0.2.0] - 2025-04-14

### Added

- Dependency tracking with threaded queue processing
- Configurable module inclusion/exclusion patterns
- Added Limitations and Gotchas to README

### Changed

- Optimized dependency graph construction
- Improved module reloading performance

## [0.1.0]

### Added

- Initial release with basic HMR functionality
- Basic dependency tracking
- Pre-reload and post-reload hooks for module reloading
- Execution as a script with `-m renovo` option
